@@ -7,6 +7,8 @@ pub use follow_up::inspect_container_status;
 pub use follow_up::tail_container_logs;
 pub use removal::remove_existing_container;
 pub use start::llvm_bitcode_generation_cmd_provider;
+pub use start::program_verification_cmd_provider;
+pub use start::source_code_restoration_cmd_provider;
 pub use start::start_container;
 pub use start::symbolic_execution_cmd_provider;
 pub use start::TARGET_RVT_DIRECTORY;
